summaryrefslogtreecommitdiff
path: root/sfx2/inc/sfx2/sfxhtml.hxx
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-07 17:35:15 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-07 17:35:15 +0100
commitc5b727675460581258489d3bd569a61184ad69cd (patch)
tree6e9cb2940cb74b5cd060a57e1db0065b07b4935c /sfx2/inc/sfx2/sfxhtml.hxx
parentdcd8e4664d9a284c24ceb0360cab0606b22cf86d (diff)
removetooltypes: #i112600# remove tooltypes
Diffstat (limited to 'sfx2/inc/sfx2/sfxhtml.hxx')
-rw-r--r--sfx2/inc/sfx2/sfxhtml.hxx40
1 files changed, 20 insertions, 20 deletions
diff --git a/sfx2/inc/sfx2/sfxhtml.hxx b/sfx2/inc/sfx2/sfxhtml.hxx
index 9b1fcf60efbb..a2d0e4162ba6 100644
--- a/sfx2/inc/sfx2/sfxhtml.hxx
+++ b/sfx2/inc/sfx2/sfxhtml.hxx
@@ -49,32 +49,32 @@ class SFX2_DLLPUBLIC SfxHTMLParser : public HTMLParser
SfxMedium* pMedium;
SfxMedium *pDLMedium; // Medium fuer Download von Files
- USHORT nMetaTags; // Anzahl der bisher gelesenen Meta-Tags
+ sal_uInt16 nMetaTags; // Anzahl der bisher gelesenen Meta-Tags
ScriptType eScriptType;
SAL_DLLPRIVATE void GetScriptType_Impl( SvKeyValueIterator* );
protected:
- SfxHTMLParser( SvStream& rStream, BOOL bNewDoc=TRUE, SfxMedium *pMedium=0 );
+ SfxHTMLParser( SvStream& rStream, sal_Bool bNewDoc=sal_True, SfxMedium *pMedium=0 );
virtual ~SfxHTMLParser();
public:
// Lesen der Optionen einer Image-Map
- // <MAP>: TRUE = Image-Map hat einen Namen
- // <AREA>: TRUE = Image-Map hat jetzt einen Bereich mehr
- static BOOL ParseMapOptions(ImageMap * pImageMap,
+ // <MAP>: sal_True = Image-Map hat einen Namen
+ // <AREA>: sal_True = Image-Map hat jetzt einen Bereich mehr
+ static sal_Bool ParseMapOptions(ImageMap * pImageMap,
const HTMLOptions * pOptions );
- BOOL ParseMapOptions(ImageMap * pImageMap)
+ sal_Bool ParseMapOptions(ImageMap * pImageMap)
{ return ParseMapOptions(pImageMap, GetOptions()); }
- static BOOL ParseAreaOptions(ImageMap * pImageMap, const String& rBaseURL,
+ static sal_Bool ParseAreaOptions(ImageMap * pImageMap, const String& rBaseURL,
const HTMLOptions * pOptions,
- USHORT nEventMouseOver = 0,
- USHORT nEventMouseOut = 0 );
- inline BOOL ParseAreaOptions(ImageMap * pImageMap, const String& rBaseURL,
- USHORT nEventMouseOver = 0,
- USHORT nEventMouseOut = 0);
+ sal_uInt16 nEventMouseOver = 0,
+ sal_uInt16 nEventMouseOut = 0 );
+ inline sal_Bool ParseAreaOptions(ImageMap * pImageMap, const String& rBaseURL,
+ sal_uInt16 nEventMouseOver = 0,
+ sal_uInt16 nEventMouseOut = 0);
// <TD SDVAL="..." SDNUM="...">
static double GetTableDataOptionsValNum( sal_uInt32& nNumForm,
@@ -102,16 +102,16 @@ protected:
// unmittelbar vor FinishFileDownload aufgerufen werden, nie aber
// danach.
- BOOL GetFileDownloadMIME( String& rMime );
+ sal_Bool GetFileDownloadMIME( String& rMime );
- // Beenden eines asynchronen File-Downloads. Gibt TRUE zurueck, wenn
+ // Beenden eines asynchronen File-Downloads. Gibt sal_True zurueck, wenn
// der Download geklappt hat. Das gelesene File befindet sich dann in
// dem uebergeben String.
- BOOL FinishFileDownload( String& rStr );
+ sal_Bool FinishFileDownload( String& rStr );
- // Gibt TRUE zurueck, wenn ein File downloaded wurde und
+ // Gibt sal_True zurueck, wenn ein File downloaded wurde und
// FileDownloadFinished noch nicht gerufen wurde.
- BOOL ShouldFinishFileDownload() const { return pDLMedium != 0; }
+ sal_Bool ShouldFinishFileDownload() const { return pDLMedium != 0; }
SfxMedium *GetMedium() { return pMedium; }
const SfxMedium *GetMedium() const { return pMedium; }
@@ -121,9 +121,9 @@ protected:
const String& GetScriptTypeString( SvKeyValueIterator* ) const;
};
-inline BOOL SfxHTMLParser::ParseAreaOptions(ImageMap * pImageMap, const String& rBaseURL,
- USHORT nEventMouseOver,
- USHORT nEventMouseOut)
+inline sal_Bool SfxHTMLParser::ParseAreaOptions(ImageMap * pImageMap, const String& rBaseURL,
+ sal_uInt16 nEventMouseOver,
+ sal_uInt16 nEventMouseOut)
{
return ParseAreaOptions( pImageMap, rBaseURL, GetOptions(),
nEventMouseOver, nEventMouseOut );